@@ -3,7 +3,7 @@ from .src import *
 def get_decode_rows(table=None,offset=None,asc=None):
     return get_latest_from_table(table=table,offset=offset,asc=asc)
 def decode_record_data(**kwargs):
-    ENV = initializeEnvironment()
+    ENV = get_decoder_env()
     signature=kwargs.get("signature")
     program_id=kwargs.get("program_id")
     data = kwargs.get("b64")
